@@ -65,6 +65,7 @@ typedef struct {
 	int   border_width;
 	unsigned long  border_color;
 	int   test_pattern;
+        int   is_override_redirect;
 } MagnifierOptions;
 
 static MagnifierOptions global_options = { ":0.0",
@@ -93,6 +94,7 @@ static MagnifierOptions global_options = { ":0.0",
 					   1,
 					   0,
 					   0,
+					   0,
 					   0
                                          };
 
@@ -122,6 +124,7 @@ struct poptOption magnifier_options [] = {
 	{"border-size", 'b', POPT_ARG_INT, &global_options.border_width, '\0', "width of border", NULL},
 	{"border-color", 'c', POPT_ARG_LONG, &global_options.border_color, '\0', "border color specified as (A)RGB 23-bit value, Alpha-MSB", NULL},
 	{"use-test-pattern", '\0', POPT_ARG_NONE, &global_options.test_pattern, '\0', "use test pattern as source", NULL},
+	{"override-redirect", '\0', POPT_ARG_NONE, &global_options.is_override_redirect, '\0', "make the magnifier window totally unmanaged by the window manager", NULL},
 	POPT_AUTOHELP
 	{NULL, 0, 0, NULL, 0, 0}
 };
@@ -382,7 +385,7 @@ main (int argc, char** argv)
   /* FIXME */
   gtk_init (&argc, &argv);
 
-  magnifier = magnifier_new ();
+  magnifier = magnifier_new (global_options.is_override_redirect);
   fprintf (stderr, "New magnifier created.\n");
   
   properties = GNOME_Magnifier_Magnifier_getProperties (
@@ -539,9 +542,12 @@ main (int argc, char** argv)
   }
   else
   {
-	  refresh_handle = g_timeout_add (
-		  global_options.refresh_time,
-		  magnifier_main_refresh_all, magnifier);
+	  if (!magnifier_source_has_damage_extension (magnifier)) 
+	  {
+		  refresh_handle = g_timeout_add (
+			  global_options.refresh_time,
+			  magnifier_main_refresh_all, magnifier);
+	  }
 	  
 	  pan_handle = g_timeout_add (
 		  global_options.mouse_poll_time,
