@@ -155,7 +155,6 @@ static float cps_max           = 0;
 static float nrr_max           = 0;
 static float update_nrr_max    = 0;
 static gboolean	reset_timing   = FALSE;
-static GdkGC *default_gc       = NULL;
 static gboolean timing_test    = FALSE;
 
 static guint pending_idle_handler = 0;
@@ -223,7 +222,6 @@ _debug_announce_rect (char *msg, GdkRectangle rect)
 }
 
 #ifdef TEST_XTST_CURSOR
-/** util stuff **/
 static Cursor *
 _get_x_cursors (Display *display)
 {
@@ -580,6 +578,19 @@ _rectangle_clip_to_bounds (GdkRectangle area,
 	return area;
 }
 
+static GdkRectangle
+zoom_region_clip_to_source (ZoomRegion *zoom_region,
+			    GdkRectangle area)
+{
+    GNOME_Magnifier_RectBounds *source_rect_ptr;
+    if (zoom_region && zoom_region->priv && zoom_region->priv->parent)
+    {
+	source_rect_ptr = &((Magnifier *)zoom_region->priv->parent)->source_bounds;
+	return _rectangle_clip_to_bounds (area, source_rect_ptr);
+    }
+    return area;
+}
+
 static GdkRectangle
 zoom_region_clip_to_exposed_target (ZoomRegion *zoom_region,
 				    GdkRectangle area)
@@ -764,10 +775,9 @@ static void
 zoom_region_paint_crosswire_cursor (ZoomRegion *zoom_region, GdkRectangle *clip_rect)
 {
 	Magnifier *magnifier = zoom_region->priv->parent;
-	static GdkGC *crosswire_gc = NULL;
 	static GdkColormap *cmap;
 	static GdkColor last_color;
-	static gboolean last_color_init = !TRUE;
+	static gboolean last_color_init = FALSE;
 	GdkGCValues values;
 	GdkRectangle rect;
 	GdkDrawable *cursor;
@@ -780,10 +790,11 @@ zoom_region_paint_crosswire_cursor (ZoomRegion *zoom_region, GdkRectangle *clip_
 	      zoom_region->priv->w->window &&
 	      magnifier->crosswire_size > 0)) return;
 
-	if (crosswire_gc == NULL) 
+	if (zoom_region->priv->crosswire_gc == NULL) 
 	{
-		crosswire_gc = gdk_gc_new (zoom_region->priv->w->window);
-		cmap = gdk_gc_get_colormap(crosswire_gc);
+		zoom_region->priv->crosswire_gc = gdk_gc_new (zoom_region->priv->w->window);
+		cmap = gdk_gc_get_colormap(zoom_region->priv->crosswire_gc);
+		last_color_init = FALSE;
 	}
 
 	if (magnifier->crosswire_color == 0)
@@ -810,11 +821,11 @@ zoom_region_paint_crosswire_cursor (ZoomRegion *zoom_region, GdkRectangle *clip_
 		if (cmap)
 		{
 			gdk_rgb_find_color (cmap, &(values.foreground));
-			gdk_gc_set_values(crosswire_gc, &values, GDK_GC_FUNCTION | GDK_GC_FOREGROUND);
+			gdk_gc_set_values(zoom_region->priv->crosswire_gc, &values, GDK_GC_FUNCTION | GDK_GC_FOREGROUND);
 		}
 		else
 		{
-			gdk_gc_set_values(crosswire_gc, &values, GDK_GC_FUNCTION);
+			gdk_gc_set_values(zoom_region->priv->crosswire_gc, &values, GDK_GC_FUNCTION);
 		}
 
 		last_color.red   = color.red;
@@ -826,7 +837,7 @@ zoom_region_paint_crosswire_cursor (ZoomRegion *zoom_region, GdkRectangle *clip_
 	rect.x = zoom_region->priv->last_cursor_pos.x;
 	rect.y = zoom_region->priv->last_cursor_pos.y;
 	rect = zoom_region_view_rect_from_source_rect (zoom_region, rect);
-	if (clip_rect) gdk_gc_set_clip_rectangle (crosswire_gc, clip_rect);
+	if (clip_rect) gdk_gc_set_clip_rectangle (zoom_region->priv->crosswire_gc, clip_rect);
 
 	if (magnifier->crosswire_clip &&
 	    (cursor = magnifier_get_cursor (magnifier)))
@@ -847,31 +858,31 @@ zoom_region_paint_crosswire_cursor (ZoomRegion *zoom_region, GdkRectangle *clip_
 	{
 		if (magnifier->crosswire_clip)
 		{
-			gdk_draw_line (zoom_region->priv->w->window, crosswire_gc, rect.x, 0,
+			gdk_draw_line (zoom_region->priv->w->window, zoom_region->priv->crosswire_gc, rect.x, 0,
 				       rect.x, y_top_clip);
-			gdk_draw_line (zoom_region->priv->w->window, crosswire_gc, 0, rect.y,
+			gdk_draw_line (zoom_region->priv->w->window, zoom_region->priv->crosswire_gc, 0, rect.y,
 				       x_left_clip, rect.y);
 		}
-		gdk_draw_line (zoom_region->priv->w->window, crosswire_gc, rect.x,
+		gdk_draw_line (zoom_region->priv->w->window, zoom_region->priv->crosswire_gc, rect.x,
 			       y_bottom_clip, rect.x, 4096);
-		gdk_draw_line (zoom_region->priv->w->window, crosswire_gc, x_right_clip,
+		gdk_draw_line (zoom_region->priv->w->window, zoom_region->priv->crosswire_gc, x_right_clip,
 			       rect.y, 4096, rect.y);
 	}
 	else
 	{
 		if (magnifier->crosswire_clip )
 		{
-			gdk_draw_rectangle (zoom_region->priv->w->window, crosswire_gc, TRUE,
+			gdk_draw_rectangle (zoom_region->priv->w->window, zoom_region->priv->crosswire_gc, TRUE,
 					    rect.x - magnifier->crosswire_size / 2,
 					    0, magnifier->crosswire_size, y_top_clip);
-			gdk_draw_rectangle (zoom_region->priv->w->window, crosswire_gc, TRUE, 0,
+			gdk_draw_rectangle (zoom_region->priv->w->window, zoom_region->priv->crosswire_gc, TRUE, 0,
 					    rect.y - magnifier->crosswire_size / 2,
 					    x_left_clip, magnifier->crosswire_size);
 		}
-		gdk_draw_rectangle (zoom_region->priv->w->window, crosswire_gc, TRUE,
+		gdk_draw_rectangle (zoom_region->priv->w->window, zoom_region->priv->crosswire_gc, TRUE,
 				    rect.x - magnifier->crosswire_size / 2,
 				    y_bottom_clip, magnifier->crosswire_size, 4096);
-		gdk_draw_rectangle (zoom_region->priv->w->window, crosswire_gc, TRUE, x_right_clip,
+		gdk_draw_rectangle (zoom_region->priv->w->window, zoom_region->priv->crosswire_gc, TRUE, x_right_clip,
 				    rect.y - magnifier->crosswire_size / 2,
 				    4096, magnifier->crosswire_size);
 	}
@@ -887,7 +898,6 @@ static void
 zoom_region_paint_cursor (ZoomRegion *zoom_region,
 			  GdkRectangle *clip_rect)
 {
-	static GdkGC *paint_cursor_gc = NULL;
 	GdkGCValues values;
 	GdkRectangle rect, intersct;
 	GdkRectangle fullscreen;
@@ -924,10 +934,10 @@ zoom_region_paint_cursor (ZoomRegion *zoom_region,
 		}
 		if (zoom_region->priv->w->window != NULL)
 		{
-			if (default_gc == NULL)
-				default_gc = gdk_gc_new(zoom_region->priv->w->window);
+			if (zoom_region->priv->default_gc == NULL) 
+				zoom_region->priv->default_gc = gdk_gc_new(zoom_region->priv->w->window);
 			gdk_draw_drawable (zoom_region->priv->cursor_backing_pixels,
-				     default_gc,
+				     zoom_region->priv->default_gc,
 				     zoom_region->priv->w->window,
 				     rect.x,
 				     rect.y,
@@ -938,18 +948,23 @@ zoom_region_paint_cursor (ZoomRegion *zoom_region,
 		DEBUG_RECT ("painting", rect);
 		if (cursor)
 		{
-			if (paint_cursor_gc == NULL)
-				paint_cursor_gc = gdk_gc_new (zoom_region->priv->w->window);
+		    if (zoom_region->priv->paint_cursor_gc == NULL)
+				zoom_region->priv->paint_cursor_gc = gdk_gc_new (zoom_region->priv->w->window);
 
-			gdk_gc_set_clip_rectangle (paint_cursor_gc, clip_rect);
+			gdk_gc_set_clip_rectangle (zoom_region->priv->paint_cursor_gc, clip_rect);
 			values.clip_x_origin = rect.x;
 			values.clip_y_origin = rect.y;
 			values.clip_mask = magnifier->priv->cursor_mask;
-			gdk_gc_set_values(paint_cursor_gc, &values, GDK_GC_CLIP_X_ORIGIN |
-				GDK_GC_CLIP_Y_ORIGIN | GDK_GC_CLIP_MASK);
+			gdk_gc_set_values(zoom_region->priv->paint_cursor_gc, &values, GDK_GC_CLIP_X_ORIGIN |
+					  GDK_GC_CLIP_Y_ORIGIN  | GDK_GC_CLIP_MASK);
+
+			gdk_draw_rectangle (zoom_region->priv->w->window,
+					   zoom_region->priv->paint_cursor_gc,
+					   TRUE,
+					   rect.x, rect.y, rect.width, rect.height);
 
 			gdk_draw_drawable (zoom_region->priv->w->window,
-					   paint_cursor_gc,
+					   zoom_region->priv->paint_cursor_gc,
 					   cursor,
 					   0, 0,
 					   rect.x,
@@ -1003,18 +1018,20 @@ zoom_region_paint_border (ZoomRegion *zoom_region,
 			  GdkRectangle *area)
 {
 	GdkColor color;
-	/*
-	if (zoom_region->border_size > 0)
+	if ((zoom_region->border_size > 0) && (zoom_region->priv->w->window))
+	{
 		if (!zoom_region->priv->border_gc)
 		{
 			zoom_region->priv->border_gc = gdk_gc_new (zoom_region->priv->w->window);
-			color.red = (zoom_region->border_color & 0xFF0000) >> 16;
-			color.green = (zoom_region->border_color & 0xFF00) >> 8;
-			color.blue = zoom_region->border_color & 0xFF;
-#ifdef DEBUG
+			color.red = (zoom_region->border_color & 0xFF0000) >> 8;
+			color.green = (zoom_region->border_color & 0xFF00);
+			color.blue = (zoom_region->border_color & 0xFF) << 8;
+#ifdef DEBUG_BORDER
 			fprintf (stderr, "border color triple RGB=%d|%d|%d",
 				 color.red, color.green, color.blue);
 #endif
+			gdk_colormap_alloc_color (gdk_drawable_get_colormap (zoom_region->priv->w->window), 
+						  &color, TRUE, TRUE);
 			gdk_gc_set_foreground (zoom_region->priv->border_gc, &color);
 		}
 		gdk_draw_rectangle (zoom_region->priv->w->window,
@@ -1024,20 +1041,20 @@ zoom_region_paint_border (ZoomRegion *zoom_region,
 				    area->y,
 				    area->width,
 				    area->height);
-	*/
+	}
 }
 
 static void
 zoom_region_paint_pixmap (ZoomRegion *zoom_region,
 			  GdkRectangle *area)
 {
-	if (default_gc == NULL)
-		default_gc = gdk_gc_new(zoom_region->priv->w->window);
+	if (zoom_region->priv->default_gc == NULL) 
+		zoom_region->priv->default_gc = gdk_gc_new(zoom_region->priv->w->window);
 
 	if (zoom_region->priv->pixmap)
 	{
 		gdk_draw_drawable (zoom_region->priv->w->window,
-				   default_gc,
+				   zoom_region->priv->default_gc,
 				   zoom_region->priv->pixmap,
 				   area->x + zoom_region->priv->exposed_bounds.x1,
 				   area->y + zoom_region->priv->exposed_bounds.y1,
@@ -1306,6 +1323,7 @@ zoom_region_recompute_exposed_bounds (ZoomRegion *zoom_region)
 static void
 zoom_region_set_cursor_pos (ZoomRegion *zoom_region, int x, int y)
 {
+
 	if (zoom_region->priv)
 	{
 		zoom_region->priv->last_cursor_pos.x = x;
@@ -1341,67 +1359,6 @@ zoom_region_update_pointer (ZoomRegion *zoom_region, gboolean draw_cursor)
 	/* TODO: there's really no reason we should be using magnifier->priv->root here */
 	if (magnifier && magnifier->priv && magnifier_get_root (magnifier))
 	{
-#ifdef TEST_XTST_CURSOR
-		int max_cursors = XC_num_glyphs;
-		int cursor_id = 2;
-		Window window = None;
-		Display *display =
-			GDK_DISPLAY_XDISPLAY (magnifier->source_display);
-		Cursor *cursors = _get_x_cursors (display);
-		Cursor cursor = cursors [cursor_id];
-		int root_x_return, root_y_return, win_x_return, win_y_return;
-		Window root_return;
-		unsigned int mask_return;
-		GdkWindow *source_root = zoom_region_source_root (zoom_region);
-		if (source_root && display)
-		{
-			Window source_root_xid = GDK_WINDOW_XID (source_root);
-			if (source_root_xid)
-				XQueryPointer (display,
-					       source_root_xid,
-					       &root_return,
-					       &window,
-					       &root_x_return, &root_y_return,
-					       &win_x_return, &win_y_return,
-					       &mask_return);
-			fprintf (stderr, "XQueryPointer window=%d\n",
-				 (int) window);
-			if (!window) window = root_return;
-		}
-		if (window && cursors) {
-			if (!cursor_window) {
-				cursor_window = XCreateSimpleWindow (display,
-						     GDK_WINDOW_XID (source_root),
-								     0, 0,
-								     100, 100, 0,
-								     0L, 0L);
-				XMapWindow (display, cursor_window);
-			}
-			XSynchronize (display, TRUE);
-			XDefineCursor (display, cursor_window, None);
-			while (!XTestCompareCurrentCursorWithWindow (
-				       display,
-				       cursor_window) &&
-			       (cursor_id < max_cursors))
-			{
-				cursor_id += 2;
-				cursor = cursors [cursor_id];
-				XDefineCursor (
-					GDK_DISPLAY_XDISPLAY (
-						magnifier->target_display),
-					cursor_window,
-					cursor);
-				XFlush (GDK_DISPLAY_XDISPLAY (
-					       magnifier->target_display));
-				XSync (GDK_DISPLAY_XDISPLAY (
-					       magnifier->target_display),
-				       FALSE);
-			}
-			XSynchronize (display, FALSE);
-			if (cursor_id >= max_cursors) cursor_id = -1;
-			fprintf (stderr, "Current cursor id = %d\n", cursor_id);
-		}
-#endif
 		gdk_window_get_pointer (
 			magnifier_get_root (magnifier),
 			&mouse_x_return,
@@ -1557,11 +1514,11 @@ zoom_region_get_source_subwindow (ZoomRegion *zoom_region,
 
 			zoom_region->priv->source_drawable = gdk_pixmap_new (NULL, width, height, 24);
 
-			if (default_gc == NULL)
-				default_gc = gdk_gc_new(zoom_region->priv->w->window);
+			if (zoom_region->priv->default_gc == NULL)
+				zoom_region->priv->default_gc = gdk_gc_new(zoom_region->priv->w->window);
 
 			gdk_draw_image (zoom_region->priv->source_drawable,
-					default_gc,
+					zoom_region->priv->default_gc,
 					test_image,
 					0, 0,
 					0, 0,
@@ -1632,7 +1589,9 @@ zoom_region_update (ZoomRegion *zoom_region,
 	GdkPixbuf *subimage;
 	GdkRectangle source_rect;
 	DEBUG_RECT ("unclipped update rect", update_rect);
-	source_rect = zoom_region_clip_to_exposed_target (zoom_region, update_rect);
+	source_rect = zoom_region_clip_to_source (zoom_region, update_rect);
+	DEBUG_RECT ("clipped to source", source_rect);
+	source_rect = zoom_region_clip_to_exposed_target (zoom_region, source_rect);
 	DEBUG_RECT ("update rect clipped to exposed target", source_rect); 
 	subimage = zoom_region_get_source_subwindow (zoom_region, source_rect);
 
@@ -1660,12 +1619,12 @@ zoom_region_update (ZoomRegion *zoom_region,
 
 		zoom_region_post_process_pixbuf (zoom_region, subimage,
 						 zoom_region->priv->scaled_pixbuf);
-		if (default_gc == NULL)
-			default_gc = gdk_gc_new(zoom_region->priv->w->window);
+		if (zoom_region->priv->default_gc == NULL)
+			zoom_region->priv->default_gc = gdk_gc_new(zoom_region->priv->w->window);
 
 #ifndef USE_GDK_PIXBUF_RENDER_TO_DRAWABLE 
 		gdk_draw_pixbuf (zoom_region->priv->pixmap,
-				 default_gc,
+				 zoom_region->priv->default_gc,
 				 zoom_region->priv->scaled_pixbuf,
 				 0,
 				 0,
@@ -1679,7 +1638,7 @@ zoom_region_update (ZoomRegion *zoom_region,
 #else
 		gdk_pixbuf_render_to_drawable (zoom_region->priv->scaled_pixbuf,
 					       zoom_region->priv->pixmap,
-					       default_gc,
+					       zoom_region->priv->default_gc,
 					       0,
 					       0,
 					       paint_rect.x + zoom_region->priv->exposed_bounds.x1,
@@ -1785,7 +1744,9 @@ zoom_region_process_updates (gpointer data)
 			zoom_region_update (zoom_region,
 					    * (GdkRectangle *) last->data);
 			g_list_free (last);
+#ifdef DEBUG
 			fputs (".\n", stderr); /* debug output, means we actually did something. */
+#endif
 		}
 		return TRUE;
 	}
@@ -2099,11 +2060,13 @@ zoom_region_set_viewport (ZoomRegion *zoom_region,
 			  const GNOME_Magnifier_RectBounds *viewport)
 {
 	zoom_region->viewport = *viewport;
+#define DEBUG
 #ifdef DEBUG
 	fprintf (stderr, "setting viewport %d,%d - %d,%d\n",
 		 (int) viewport->x1, (int) viewport->y1,
 		 (int) viewport->x2, (int) viewport->y2);
 #endif
+#undef DEBUG
 	zoom_region_recompute_exposed_viewport (zoom_region);
 	zoom_region_align (zoom_region);
 	if (!zoom_region->priv->w) {
@@ -2136,11 +2099,14 @@ zoom_region_get_property (BonoboPropertyBag *bag,
 	ZoomRegion *zoom_region = user_data;
 	
 	switch (arg_id) {
+	case ZOOM_REGION_MANAGED_PROP:
+		BONOBO_ARG_SET_BOOLEAN (arg, zoom_region->is_managed);
+		break;
 	case ZOOM_REGION_INVERT_PROP:
 		BONOBO_ARG_SET_BOOLEAN (arg, zoom_region->invert);
 		break;
 	case ZOOM_REGION_SMOOTHSCROLL_PROP:
-		BONOBO_ARG_SET_INT (arg, zoom_region->smooth_scroll_policy);
+		BONOBO_ARG_SET_SHORT (arg, zoom_region->smooth_scroll_policy);
 		break;
 	case ZOOM_REGION_TESTPATTERN_PROP:
 		BONOBO_ARG_SET_BOOLEAN (arg, zoom_region->priv->test);
@@ -2158,7 +2124,7 @@ zoom_region_get_property (BonoboPropertyBag *bag,
 		BONOBO_ARG_SET_FLOAT (arg, zoom_region->yscale);
 		break;
 	case ZOOM_REGION_BORDERSIZE_PROP:
-		BONOBO_ARG_SET_INT (arg, zoom_region->border_size);
+		BONOBO_ARG_SET_LONG (arg, zoom_region->border_size);
 		break;
 	case ZOOM_REGION_XALIGN_PROP:
 		/* TODO: enums here */
@@ -2170,6 +2136,7 @@ zoom_region_get_property (BonoboPropertyBag *bag,
 	case ZOOM_REGION_BORDERCOLOR_PROP:
 		BONOBO_ARG_SET_LONG (arg,
 				     zoom_region->border_color);
+		break;
 	case ZOOM_REGION_VIEWPORT_PROP:
 		BONOBO_ARG_SET_GENERAL (arg, zoom_region->viewport,
 					TC_GNOME_Magnifier_RectBounds,
@@ -2203,17 +2170,16 @@ zoom_region_set_property (BonoboPropertyBag *bag,
 	ZoomRegion *zoom_region = user_data;
 	GNOME_Magnifier_RectBounds bounds;
 
-	fprintf (stderr, "Setting zoom region property\n");
-	
 	switch (arg_id) {
+	case ZOOM_REGION_MANAGED_PROP:
+		zoom_region->is_managed = BONOBO_ARG_GET_BOOLEAN (arg);
+		break;
 	case ZOOM_REGION_INVERT_PROP:
 		zoom_region->invert = BONOBO_ARG_GET_BOOLEAN (arg);
 		zoom_region_update_current (zoom_region);
 		break;
 	case ZOOM_REGION_SMOOTHSCROLL_PROP:
-		zoom_region->smooth_scroll_policy = BONOBO_ARG_GET_INT (arg);
-		fprintf (stderr, "Setting scroll smoothness property to %d\n",
-			zoom_region->smooth_scroll_policy);
+		zoom_region->smooth_scroll_policy = BONOBO_ARG_GET_SHORT (arg);
 		break;
 	case ZOOM_REGION_SMOOTHING_PROP:
 		zoom_region->smoothing = BONOBO_ARG_GET_STRING (arg);
@@ -2242,14 +2208,14 @@ zoom_region_set_property (BonoboPropertyBag *bag,
 		zoom_region_update_current (zoom_region);
 		break;
 	case ZOOM_REGION_BORDERSIZE_PROP:
-		zoom_region->border_size = BONOBO_ARG_GET_INT (arg);
+		zoom_region->border_size = BONOBO_ARG_GET_LONG (arg);
+	    g_message ("border size set to %d", zoom_region->border_size);
 		zoom_region_recompute_exposed_viewport (zoom_region);
 		zoom_region_update_current (zoom_region);
 		break;
 	case ZOOM_REGION_BORDERCOLOR_PROP:
 		zoom_region->border_color =
 			BONOBO_ARG_GET_LONG (arg);
-		fprintf (stderr, "border color = %x\n", (unsigned) zoom_region->border_color);
 		if (zoom_region->priv->border_gc)
 			g_object_unref (zoom_region->priv->border_gc);
 		zoom_region->priv->border_gc = NULL;
@@ -2257,8 +2223,6 @@ zoom_region_set_property (BonoboPropertyBag *bag,
 		break;
 	case ZOOM_REGION_XALIGN_PROP:
 		zoom_region->x_align_policy = BONOBO_ARG_GET_INT (arg);
-		fprintf (stderr, "Setting x-alignment property to %d\n",
-			zoom_region->x_align_policy);
 		zoom_region_update_current (zoom_region);
 		break;
 	case ZOOM_REGION_YALIGN_PROP:
@@ -2267,7 +2231,6 @@ zoom_region_set_property (BonoboPropertyBag *bag,
 		zoom_region_update_current (zoom_region);
 		break;
 	case ZOOM_REGION_VIEWPORT_PROP:
-		fprintf (stderr, "setting viewport property...\n");
 		bounds = BONOBO_ARG_GET_GENERAL (arg,
 						 TC_GNOME_Magnifier_RectBounds,
 						 GNOME_Magnifier_RectBounds,
@@ -2277,26 +2240,16 @@ zoom_region_set_property (BonoboPropertyBag *bag,
 	case ZOOM_REGION_TIMING_TEST_PROP:
 		zoom_region->timing_iterations = BONOBO_ARG_GET_INT (arg);
 		timing_test = TRUE;
-		fprintf (stderr, "Setting timing iterations property to %d\n", zoom_region->timing_iterations);
 		break;
 	case ZOOM_REGION_TIMING_OUTPUT_PROP:
 		zoom_region->timing_output = BONOBO_ARG_GET_BOOLEAN (arg);
-		if (zoom_region->timing_output)
-			fprintf (stderr, "Setting timing output property to true\n");
-		else
-			fprintf (stderr, "Setting timing output property to false\n");
 		break;
 	case ZOOM_REGION_TIMING_PAN_RATE_PROP:
 		zoom_region->timing_pan_rate = BONOBO_ARG_GET_INT (arg);
 		timing_test = TRUE;
-		fprintf (stderr, "Setting timing pan rate property to %d\n", zoom_region->timing_pan_rate);
 		break;
 	case ZOOM_REGION_EXIT_MAGNIFIER:
 		zoom_region->exit_magnifier = BONOBO_ARG_GET_BOOLEAN (arg);
-		if (zoom_region->exit_magnifier)
-			fprintf (stderr, "Setting exit magnifier property to true\n");
-		else
-			fprintf (stderr, "Setting exit magnifier property to false\n");
 		break;
 	default:
 		bonobo_exception_set (ev, ex_Bonobo_PropertyBag_NotFound);
@@ -2471,7 +2424,7 @@ impl_zoom_region_set_mag_factor (PortableServer_Servant servant,
 			BONOBO_OBJREF (
 				(Magnifier *) zoom_region->priv->parent), ev);
 	any = Bonobo_PropertyBag_getValue (
-		properties, "source-display-size", ev);
+		properties, "source-display-bounds", ev);
 	if (!BONOBO_EX (ev))
 		zoom_region->priv->source_area =
 			*((GNOME_Magnifier_RectBounds *) any->_value);
@@ -2545,11 +2498,12 @@ impl_zoom_region_mark_dirty (PortableServer_Servant servant,
 {
 	ZoomRegion *zoom_region =
 		ZOOM_REGION (bonobo_object_from_servant (servant));
-	DEBUG_RECT ("mark dirty", zoom_region_source_rect_clipto_view_bounds (
+	DEBUG_RECT ("mark dirty", zoom_region_rect_from_bounds (
 			    zoom_region, roi_dirty) );
 	zoom_region_update_pointer (zoom_region, FALSE);
-	zoom_region_queue_update (zoom_region, zoom_region_clip_to_target
-				  (zoom_region, zoom_region_rect_from_bounds (zoom_region, roi_dirty)));
+	zoom_region_queue_update (zoom_region, 
+	  zoom_region_clip_to_target (zoom_region, 
+	      zoom_region_rect_from_bounds (zoom_region, roi_dirty)));
 }
 
 static GNOME_Magnifier_RectBounds
@@ -2650,13 +2604,13 @@ zoom_region_properties_init (ZoomRegion *zoom_region)
 				 Bonobo_PROPERTY_WRITEABLE);
 
 	bonobo_arg_release (def);
-	def = bonobo_arg_new (BONOBO_ARG_INT);
-	BONOBO_ARG_SET_INT (def, GNOME_Magnifier_ZoomRegion_SCROLL_FASTEST);
+	def = bonobo_arg_new (BONOBO_ARG_SHORT);
+	BONOBO_ARG_SET_SHORT (def, GNOME_Magnifier_ZoomRegion_SCROLL_FASTEST);
 	
 	bonobo_property_bag_add (zoom_region->properties,
 				 "smooth-scroll-policy",
 				 ZOOM_REGION_SMOOTHSCROLL_PROP,
-				 BONOBO_ARG_INT,
+				 BONOBO_ARG_SHORT,
 				 def,
 				 "scrolling policy, slower versus faster",
 				 Bonobo_PROPERTY_READABLE |
@@ -2738,13 +2692,13 @@ zoom_region_properties_init (ZoomRegion *zoom_region)
 				 Bonobo_PROPERTY_WRITEABLE);
 
 	bonobo_arg_release (def);
-	def = bonobo_arg_new (BONOBO_ARG_INT);
-	BONOBO_ARG_SET_INT (def, 0);
+	def = bonobo_arg_new (BONOBO_ARG_LONG);
+	BONOBO_ARG_SET_LONG (def, 0);
 	
 	bonobo_property_bag_add (zoom_region->properties,
 				 "border-size",
 				 ZOOM_REGION_BORDERSIZE_PROP,
-				 BONOBO_ARG_INT,
+				 BONOBO_ARG_LONG,
 				 def,
 				 "size of zoom-region borders, in pixels",
 				 Bonobo_PROPERTY_READABLE |
@@ -2861,6 +2815,9 @@ zoom_region_private_init (ZoomRegionPrivate *priv)
 	GdkRectangle rect = {0, 0, 0, 0};
 	priv->parent = NULL;
 	priv->w = NULL;
+	priv->default_gc = NULL;
+	priv->paint_cursor_gc = NULL;
+	priv->crosswire_gc = NULL;
 	priv->q = NULL;
 	priv->scaled_pixbuf = NULL;
 	priv->source_pixbuf_cache = NULL;
